@@ -12,9 +12,9 @@ import { IDocumentManager } from '@jupyterlab/docmanager';
 import { FileBrowser } from '@jupyterlab/filebrowser';
 import { INotebookTracker } from '@jupyterlab/notebook';
 import { StatusButton } from './components/StatusButton';
-import {  ERROR_LABEL  } from './utils';
+import { ERROR_LABEL } from './utils';
 import { showErrorDialog } from './components/props';
-import {showLogin2Dialog} from "./components/Login2";
+import { showLogin2Dialog } from './components/Login2';
 
 export var runningVdkOperation = '';
 
@@ -25,11 +25,11 @@ export function updateVDKMenu(
   notebookTracker: INotebookTracker,
   statusButton: StatusButton
 ) {
-
   commands.addCommand('jp-vdk:menu-login', {
     label: 'Login',
     caption: 'Execute VDK Login Command',
-    execute: showLogin2Dialog });
+    execute: showLogin2Dialog
+  });
 
   // Add Run job command
   add_command(
@@ -82,7 +82,8 @@ export function updateVDKMenu(
     'Deploy',
     'Create deployment of a VDK job',
     showCreateDeploymentDialog,
-    statusButton
+    statusButton,
+    docManager
   );
 }
 
