@@ -6,8 +6,9 @@ import { Dialog, showDialog } from '@jupyterlab/apputils';
 import { jobRequest } from '../serverRequests';
 import { IJobFullProps } from './props';
 import { CREATE_JOB_BUTTON_LABEL } from '../utils';
+import { StatusButton } from './StatusButton';
 
-export default class CreateJobDialog extends Component<(IJobFullProps)> {
+export default class CreateJobDialog extends Component<IJobFullProps> {
   /**
    * Returns a React component for rendering a create menu.
    *
@@ -39,13 +40,15 @@ export default class CreateJobDialog extends Component<(IJobFullProps)> {
           option={VdkOption.PATH}
           value={this.props.jobPath}
           label="Path to job directory:"
+          tooltip="Specify the directory for the new job folder, e.g., 'x/y' with job name 'foo' becomes 'x/y/foo'. If left blank, it defaults to the Jupyter's main directory."
         ></VDKTextInput>
       </>
     );
   }
 }
 
-export async function showCreateJobDialog() {
+export async function showCreateJobDialog(statusButton: StatusButton) {
+  jobData.set(VdkOption.PATH, ''); // the default jobPath is the Jupyter root
   const result = await showDialog({
     title: CREATE_JOB_BUTTON_LABEL,
     body: (
@@ -58,11 +61,12 @@ export async function showCreateJobDialog() {
     buttons: [Dialog.okButton(), Dialog.cancelButton()]
   });
   if (result.button.accept) {
-     // We only handle the successful deployment scenario.
-     // The failing scenario is handled in the request itself.
-     const creation = await jobRequest('create');
-        if(creation.isSuccessful && creation.message){
-          alert(creation.message);
-        }
+    statusButton.show('Create', jobData.get(VdkOption.PATH)!);
+    // We only handle the successful deployment scenario.
+    // The failing scenario is handled in the request itself.
+    const creation = await jobRequest('create');
+    if (creation.isSuccessful && creation.message) {
+      alert(creation.message);
+    }
   }
 }
