@@ -5,9 +5,15 @@ import VDKTextInput from './VdkTextInput';
 import { Dialog, showDialog, showErrorMessage } from '@jupyterlab/apputils';
 import { jobRequest, jobRunRequest } from '../serverRequests';
 import { IJobFullProps } from './props';
-import { CREATE_DEP_BUTTON_LABEL, RUN_JOB_BUTTON_LABEL } from '../utils';
+import {
+  CREATE_DEP_BUTTON_LABEL,
+  RUN_JOB_BUTTON_LABEL,
+  RUN_LOG_FILE
+} from '../utils';
 import { VdkErrorMessage } from './VdkErrorMessage';
 import { VDKCheckbox } from './VdkCheckbox';
+import { StatusButton } from './StatusButton';
+import { IDocumentManager } from '@jupyterlab/docmanager';
 
 export default class DeployJobDialog extends Component<IJobFullProps> {
   /**
@@ -44,7 +50,7 @@ export default class DeployJobDialog extends Component<IJobFullProps> {
         ></VDKTextInput>
         <VDKTextInput
           option={VdkOption.DEPLOYMENT_REASON}
-          value="reason"
+          value=""
           label="Deployment reason:"
         ></VDKTextInput>
       </>
@@ -52,7 +58,10 @@ export default class DeployJobDialog extends Component<IJobFullProps> {
   }
 }
 
-export async function showCreateDeploymentDialog() {
+export async function showCreateDeploymentDialog(
+  docManager?: IDocumentManager,
+  statusButton?: StatusButton
+) {
   let runBeforeDeploy = true;
 
   const result = await showDialog({
@@ -65,11 +74,11 @@ export async function showCreateDeploymentDialog() {
           jobTeam={jobData.get(VdkOption.TEAM) || ''}
         />
         <VDKCheckbox
-                    checked={true}
-                    onChange={(checked) => runBeforeDeploy = checked}
-                    label="Run data job before deployment"
-                    id="deployRun"
-                />
+          checked={true}
+          onChange={checked => (runBeforeDeploy = checked)}
+          label="Run data job before deployment"
+          id="deployRun"
+        />
       </>
     ),
     buttons: [Dialog.okButton(), Dialog.cancelButton()]
@@ -81,14 +90,18 @@ export async function showCreateDeploymentDialog() {
     (await checkIfVdkOptionDataIsDefined(VdkOption.DEPLOYMENT_REASON))
   ) {
     try {
+      statusButton?.show('Deploy', jobData.get(VdkOption.PATH)!);
       if (runBeforeDeploy) {
+        docManager?.closeFile(RUN_LOG_FILE);
         const run = await jobRunRequest();
         if (run.isSuccessful) {
           const deployment = await jobRequest('deploy');
           // We only handle the successful deployment scenario.
           // The failing scenario is handled in the request itself.
-          if(deployment.isSuccessful && deployment.message){
-            alert("The test job run completed successfully! \n" + deployment.message);
+          if (deployment.isSuccessful && deployment.message) {
+            alert(
+              'The test job run completed successfully! \n' + deployment.message
+            );
           }
         } else {
           const errorMessage = new VdkErrorMessage('ERROR : ' + run.message);
@@ -106,9 +119,10 @@ export async function showCreateDeploymentDialog() {
             buttons: [Dialog.okButton()]
           });
         }
+        docManager?.open(RUN_LOG_FILE);
       } else {
         const deployment = await jobRequest('deploy');
-        if(deployment.isSuccessful && deployment.message){
+        if (deployment.isSuccessful && deployment.message) {
           alert(deployment.message);
         }
       }
