@@ -40,6 +40,7 @@ export default class DownloadJobDialog extends Component<IJobPathProp> {
           option={VdkOption.PATH}
           value={this.props.jobPath}
           label="Path to job directory:"
+          tooltip="Specify the directory for the new job folder, e.g., 'x/y' with job name 'foo' becomes 'x/y/foo'. If left blank, it defaults to the Jupyter's main directory."
         ></VDKTextInput>
       </>
     );
@@ -47,6 +48,7 @@ export default class DownloadJobDialog extends Component<IJobPathProp> {
 }
 
 export async function showDownloadJobDialog(statusButton?: StatusButton) {
+  jobData.set(VdkOption.PATH, ''); // the default jobPath is the Jupyter root
   const result = await showDialog({
     title: DOWNLOAD_JOB_BUTTON_LABEL,
     body: (
