@@ -7,7 +7,11 @@ import { getNotebookInfo, jobRunRequest } from '../serverRequests';
 import { IJobPathProp, showErrorDialog } from './props';
 import { VdkErrorMessage } from './VdkErrorMessage';
 import { IDocumentManager } from '@jupyterlab/docmanager';
-import { RUN_FAILED_BUTTON_LABEL, RUN_JOB_BUTTON_LABEL } from '../utils';
+import {
+  RUN_FAILED_BUTTON_LABEL,
+  RUN_JOB_BUTTON_LABEL,
+  RUN_LOG_FILE
+} from '../utils';
 import { StatusButton } from './StatusButton';
 import { checkIcon } from '@jupyterlab/ui-components';
 
@@ -18,10 +22,10 @@ export default class RunJobDialog extends Component<IJobPathProp> {
    * @param props - component properties
    * @returns React component
    */
-
   constructor(props: IJobPathProp) {
     super(props);
   }
+
   /**
    * Renders a dialog for running a data job.
    *
@@ -34,20 +38,13 @@ export default class RunJobDialog extends Component<IJobPathProp> {
           option={VdkOption.PATH}
           value={this.props.jobPath}
           label="Path to job directory:"
-        ></VDKTextInput>
-        <div className="jp-vdk-input-wrapper">
-          <label className="jp-vdk-label" htmlFor="arguments">
-            Arguments:
-          </label>
-          <input
-            type="text"
-            id="arguments"
-            className="jp-vdk-input"
-            placeholder='{"key": "value"}'
-            onChange={this._onArgsChange}
-          />
-        </div>
-        <ul id="argumentsUl" className="hidden"></ul>
+        />
+        <VDKTextInput
+          option={VdkOption.ARGUMENTS}
+          value={'{"key": "value"}'}
+          label="Arguments:"
+          onChange={this._onArgsChange}
+        />
       </>
     );
   }
@@ -85,7 +82,9 @@ export async function showRunJobDialog(
   });
   if (result.button.accept) {
     statusButton?.show('Run', jobData.get(VdkOption.PATH)!);
+    docManager?.closeFile(RUN_LOG_FILE);
     let { message, isSuccessful } = await jobRunRequest();
+    docManager?.confirmClosingDocument;
     if (isSuccessful) {
       showDialog({
         title: RUN_JOB_BUTTON_LABEL,
@@ -99,7 +98,9 @@ export async function showRunJobDialog(
         ),
         buttons: [Dialog.okButton()]
       });
+      docManager?.open(RUN_LOG_FILE);
     } else {
+      docManager?.open(RUN_LOG_FILE);
       message = 'ERROR : ' + message;
       const errorMessage = new VdkErrorMessage(message);
       if (
@@ -124,12 +125,15 @@ export async function showRunJobDialog(
 export const findFailingCellId = (message: String): string => {
   const regex = /cell_id:([0-9a-fA-F-]+)/;
   const match = message.match(regex);
-  if (match) return match[1];
+  if (match) {
+    return match[1];
+  }
   return '';
 };
 
 /**
- * Returns a Element that is used for numerating cell executions on Jupyter (text with [] if not executed and  with [1], [2] if executed)
+ * Returns an Element that is used for numerating cell executions on Jupyter
+ * (text with [] if not executed and  with [1], [2] if executed)
  * @param failingCell - parent cell of that element
  * @returns Element or undefined if the element could not be found
  */
@@ -140,8 +144,9 @@ export const getCellInputAreaPrompt = (
     'jp-Cell-inputWrapper'
   );
   for (let i = 0; i < cellInputWrappers.length; i++) {
-    const cellAreas =
-      cellInputWrappers[i].getElementsByClassName('jp-Cell-inputArea');
+    const cellAreas = cellInputWrappers[i].getElementsByClassName(
+      'jp-Cell-inputArea'
+    );
     if (cellAreas.length > 0) {
       const cellInputArea = cellAreas[0];
       const promptElements = cellInputArea.getElementsByClassName(
@@ -207,7 +212,7 @@ export const findFailingCellInNotebookCells = async (
 };
 
 /**
- * Seperate handling for notebook errors - option for the user to navigate to the failing cell when error is produced
+ * Separate handling for notebook errors - option for the user to navigate to the failing cell when error is produced
  */
 export const handleErrorsProducedByNotebookCell = async (
   message: VdkErrorMessage,
