@@ -8,7 +8,6 @@ export const CREATE_DEP_BUTTON_LABEL = 'Create Deployment';
 export const CREATE_JOB_BUTTON_LABEL = 'Create Job';
 export const RUN_FAILED_BUTTON_LABEL = 'Run Failed';
 export const DOWNLOAD_JOB_BUTTON_LABEL = 'Download Job';
-export const DELETE_JOB_BUTTON_LABEL = 'Delete Job';
 export const LOGIN_BUTTON_LABEL = 'Login into VDK Control Service';
 export const STATUS_BUTTON_LABEL = 'Status';
 export const STATUS_BUTTON_CLASS = 'jp-vdk-check-status-button';
@@ -19,3 +18,4 @@ export const ERROR_DIALOG_CLASS = 'vdk-error-dialog';
 export const LOGIN2_INPUT_CLASS = 'jp-vdk-login2-input';
 export const LOGIN2_BUTTON_CLASS = 'jp-vdk-login2-button';
 export const LOGIN2_DIALOG_CLASS = 'jp-vdk-login2-dialog-container';
+export const RUN_LOG_FILE = 'vdk_run.log';
