@@ -11,7 +11,7 @@ const baseConfig = require('@jupyterlab/galata/lib/playwright-config');
 module.exports = {
   ...baseConfig,
   webServer: {
-    command: 'jlpm start',
+    command: 'jlpm start --allow-root',
     url: 'http://localhost:8888/lab',
     timeout: 200 * 100000,
     reuseExistingServer: !process.env.CI
