@@ -9,8 +9,8 @@ import subprocess
 import tempfile
 from pathlib import Path
 
+from vdk.internal.builtin_plugins.run.summary_output import JobSummaryParser
 from vdk.internal.control.command_groups.job.create import JobCreate
-from vdk.internal.control.command_groups.job.delete import JobDelete
 from vdk.internal.control.command_groups.job.deploy_cli_impl import JobDeploy
 from vdk.internal.control.command_groups.job.download_job import JobDownloadSource
 from vdk.internal.control.utils import cli_utils
@@ -48,10 +48,7 @@ class VdkUI:
         :param arguments: the additional variables for the job run
         :return: response with status code.
         """
-        if not os.path.exists(path):
-            path = os.getcwd() + path
-            if not os.path.exists(path):
-                return {"message": f"Incorrect path! {path} does not exist!"}
+        path = expand_path(path)
         script_files = [
             x
             for x in Path(path).iterdir()
@@ -63,49 +60,44 @@ class VdkUI:
         ]
         if len(script_files) == 0:
             return {"message": f"No steps were found in {path}!"}
-        with open("vdk_logs.txt", "w+") as log_file:
-            path = shlex.quote(path)
-            cmd: list[str] = ["vdk", "run", f"{path}"]
-            if arguments:
-                arguments = shlex.quote(arguments)
-                cmd.append("--arguments")
-                cmd.append(f"{arguments}")
-            process = subprocess.Popen(
-                cmd,
-                stdout=log_file,
-                stderr=log_file,
-                env=os.environ.copy(),
-                shell=False,
-            )
-            process.wait()
-            if process.returncode != 0:
-                job_name = (
-                    os.path.basename(path[:-1])
-                    if path.endswith("/")
-                    else os.path.basename(path)
-                )
-                error_file = os.path.join(
-                    os.path.dirname(path), f".{job_name}_error.json"
-                )
-                if os.path.exists(error_file):
-                    with open(error_file) as file:
-                        # the json is generated in vdk-notebook plugin
-                        # you can see /vdk-notebook/src/vdk/notebook-plugin.py
-                        error = json.load(file)
-                        return {"message": error["details"]}
-            return {"message": process.returncode}
+        with open("vdk_run.log", "w+") as log_file:
+            cmd = VdkUI.__prepare_vdk_run_command(arguments, path)
+            with tempfile.NamedTemporaryFile(
+                prefix="jupyter-run-summary-", mode="w+"
+            ) as summary_output_file:
+                environ_copy = os.environ.copy()
+                environ_copy["JOB_RUN_SUMMARY_FILE_PATH"] = summary_output_file.name
+                # We add the PYTHONUNBUFFERED env variable to ensure print statements inside user jobs are correctly
+                # interspersed in between the rest of the job logs instead of being placed at the end
+                environ_copy["PYTHONUNBUFFERED"] = "x"
+
+                try:
+                    process = subprocess.Popen(
+                        cmd,
+                        stdout=log_file,
+                        stderr=log_file,
+                        env=environ_copy,
+                        shell=False,
+                    )
+                    process.wait()
+                    if process.returncode != 0:
+                        content = pathlib.Path(summary_output_file.name).read_text()
+                        job_summary = JobSummaryParser.from_json(content)
+                        return {"message": job_summary.details}
+                    else:
+                        return {"message": process.returncode}
+                except Exception as e:
+                    return {"message": f"Unhandled exception: {e}"}
 
     @staticmethod
-    def delete_job(name: str, team: str) -> str:
-        """
-        Execute `delete job`.
-        :param name: the name of the data job that will be deleted
-        :param team: the team of the data job that will be deleted
-        :return: message that the job is deleted
-        """
-        cmd = JobDelete(RestApiUrlConfiguration.get_rest_api_url())
-        cmd.delete_job(name, team)
-        return f"Deleted the job with name {name} from {team} team. "
+    def __prepare_vdk_run_command(arguments, path):
+        path = shlex.quote(str(path))
+        cmd: list[str] = ["vdk", "run", f"{path}"]
+        if arguments:
+            arguments = shlex.quote(arguments)
+            cmd.append("--arguments")
+            cmd.append(f"{arguments}")
+        return cmd
 
     @staticmethod
     def download_job(name: str, team: str, path: str) -> str:
@@ -117,7 +109,7 @@ class VdkUI:
         :return: message that the job is downloaded
         """
         cmd = JobDownloadSource(RestApiUrlConfiguration.get_rest_api_url())
-        cmd.download(team, name, path)
+        cmd.download(team, name, expand_path(path))
         return f"Downloaded the job with name {name} to {path}. "
 
     @staticmethod
@@ -142,7 +134,9 @@ class VdkUI:
         except ValueError as e:
             error = str(e)
         cmd = JobCreate(rest_api_url)
-        cmd.create_job(name, team, path, cloud, True, pathlib.Path(jupyter_job_dir))
+        cmd.create_job(
+            name, team, expand_path(path), cloud, True, pathlib.Path(jupyter_job_dir)
+        )
         if cloud:
             result = f"Job with name {name} was created successfully!"
         else:
@@ -166,6 +160,7 @@ class VdkUI:
         :param reason: the reason of deployment
         :return: output string of the operation
         """
+        path = expand_path(path)
         with tempfile.TemporaryDirectory() as temp_dir:
             if not os.path.exists(path):
                 raise NotADirectoryError(
@@ -222,7 +217,7 @@ class VdkUI:
              if the specified parent directory does not exist, an empty dictionary is returned.
         """
         if not os.path.exists(pr_path):
-            pr_path = os.getcwd() + pr_path
+            pr_path = expand_path(pr_path)
             if not os.path.exists(pr_path):
                 return {"path": "", "cellIndex": ""}
         notebook_files = [
@@ -251,8 +246,8 @@ class VdkUI:
              If the specified notebook path does not exist, an empty list is returned.
         """
         if not os.path.exists(notebook_path):
-            job_notebook = os.getcwd() + notebook_path
-            if not os.path.exists(job_notebook):
+            notebook_path = expand_path(notebook_path)
+            if not os.path.exists(notebook_path):
                 return []
         with open(notebook_path) as f:
             notebook_json = json.load(f)
@@ -270,7 +265,7 @@ class VdkUI:
         :param job_dir: Path to the directory of the job to be transformed.
         :return: The processed code structure.
         """
-        job_dir = Path(job_dir)
+        job_dir = Path(expand_path(job_dir))
         archiver = DirectoryArchiver(job_dir)
         processor = ConvertJobDirectoryProcessor(job_dir)
         archiver.archive_folder()
@@ -281,3 +276,13 @@ class VdkUI:
         }
         processor.cleanup()
         return message
+
+
+def expand_path(path: str):
+    """
+    Expands the path parameter to be rooted at the file system location where Jupyter was initially ran.
+
+    :param path: path parameter provided by the user
+    :return: expanded path
+    """
+    return pathlib.Path(os.getcwd()).joinpath(path)
